@@ -31,7 +31,7 @@ urlpatterns = patterns(
         r'^password/change/$',
         auth_views.password_change,
         {'template_name': 'registration/password_change_form_custom.html'},
-        name='auth_password_change',
+        name='password_change',
     ),
     url(
         r'^password/change/done/$',
@@ -44,24 +44,24 @@ urlpatterns = patterns(
         r'^password/reset/$',
         auth_views.password_reset,
         {'template_name': 'registration/password_reset_form.html'},
-        name='auth_password_reset',
+        name='password_reset',
     ),
     url(
-        r'^password/reset/confirm/(?P<uidb36>[0-9A-Za-z]+)-(?P<token>.+)/$',
+        r'^password/reset/confirm/(?P<uidb64>[0-9A-Za-z]+)-(?P<token>.+)/$',
         auth_views.password_reset_confirm,
         {'template_name': 'registration/password_reset_confirm.html'},
-        name='auth_password_reset_confirm',
+        name='password_reset_confirm',
     ),
     url(
         r'^password/reset/complete/$',
         auth_views.password_reset_complete,
         {'template_name': 'registration/password_reset_complete.html'},  # NOQA
-        name='auth_password_reset_complete',
+        name='password_reset_complete',
     ),
     url(
         r'^password/reset/done/$',
         auth_views.password_reset_done,
         {'template_name': 'registration/password_reset_done.html'},
-        name='auth_password_reset_done',
+        name='password_reset_done',
     ),
 )
